==> org.eclipse.gmt.modisco.infra.browser.custom.examples.uml_0.8.0.201002191721.jar: src/org/eclipse/gmt/modisco/infra/browser/custom/examples/uml/SubClassifiers.java <==
/*******************************************************************************
 * Copyright (c) 2009 Mia-Software.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Grgoire Dup (Mia-Software)
 *******************************************************************************/
package org.eclipse.gmt.modisco.infra.browser.custom.examples.uml;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.gmt.modisco.infra.query.core.exception.ModelQueryExecutionException;
import org.eclipse.gmt.modisco.infra.query.core.java.IJavaModelQuery;
import org.eclipse.gmt.modisco.infra.query.runtime.ModelQueryParameterValue;
import org.eclipse.uml2.uml.Classifier;


/**
 * @author Gregoire Dupe (Mia-Software)
 */
public class SubClassifiers implements IJavaModelQuery {

	public Object evaluate(EObject context,
			List<ModelQueryParameterValue> parameterValues)
			throws ModelQueryExecutionException {
		if (context instanceof Classifier) {
			return evaluate((Classifier) context);
		}
		throw new ModelQueryExecutionException(
				"An instance of Classifier is expected as contxt parameter."); //$NON-NLS-1$
	}

	public List<Classifier> evaluate(Classifier context) {
		List<Classifier> result = new ArrayList<Classifier>();
		org.eclipse.uml2.uml.Model model = (org.eclipse.uml2.uml.Model) new Model()
				.evaluate(context);
		for (Classifier classifier : new AllClassifiers_Package()
				.evaluate(model)) {
			if (new IsParent().evaluate(classifier, context)) {
				result.add(classifier);
			}
		}
		return result;
	}

}

==> org.eclipse.gmt.modisco.infra.browser.custom.examples.uml_0.12.1.201408191633.jar: src/org/eclipse/gmt/modisco/infra/browser/custom/examples/uml/SubClassifiers.java <==
/*******************************************************************************
 * Copyright (c) 2009 Mia-Software.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Gregoire DUPE (Mia-Software)
 *******************************************************************************/
package org.eclipse.gmt.modisco.infra.browser.custom.examples.uml;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.gmt.modisco.infra.query.core.exception.ModelQueryExecutionException;
import org.eclipse.gmt.modisco.infra.query.core.java.IJavaModelQuery;
import org.eclipse.gmt.modisco.infra.query.core.java.ParameterValueList;
import org.eclipse.uml2.uml.Classifier;

/**
 * @author Gregoire DUPE (Mia-Software)
 */
public class SubClassifiers implements
		IJavaModelQuery<Classifier, List<Classifier>> {

	public List<Classifier> evaluate(final Classifier context,
			final ParameterValueList parameterValues)
			throws ModelQueryExecutionException {
		List<Classifier> result = new ArrayList<Classifier>();
		org.eclipse.uml2.uml.Model model = (org.eclipse.uml2.uml.Model) new Model()
				.evaluate(context, null);
		for (Classifier classifier : new AllClassifiersPackage().evaluate(
				model, null)) {
			if (new IsParent().evaluate(
					classifier,
					new ParameterValueList(IsParent
							.createParentParameterValue(context)))
					.booleanValue()) {
				result.add(classifier);
			}

		}
		return result;
	}
}
